@@ -2,6 +2,7 @@ package My::DLL;
 
 use strict;
 use warnings;
+use v5.10;
 use autodie qw( :all );  # need IPC::System::Simple
 use Alien::TinyCC;
 use Archive::Ar 2.02;
@@ -23,24 +24,12 @@ my $share = Path::Class::File
   ->parent
   ->subdir('share');
 
-my $log = $share->file('build.log')->opena;
-
 sub tcc_clean
 {
-  print $log "--- clean ", time, '---', "\n";
-  for(grep { $_->basename =~ /^libtcc\./ } $share->children)
-  {
-    print $log "unlink $_", "\n";
-    unlink $_;
-  }
+  unlink $_ for grep { $_->basename =~ /^libtcc\./ } $share->children;
   if(-d $share->subdir('lib'))
   {
-    for($share->subdir('lib')->children)
-    {
-      print $log "unlink $_", "\n";
-      unlink $_;
-    }
-    print $log "rmdir " . $share->subdir('lib'), "\n";
+    unlink $_ for $share->subdir('lib')->children;
     rmdir $share->subdir('lib');
   }
 }
@@ -48,8 +37,6 @@ sub tcc_clean
 sub tcc_build
 {
   tcc_clean();
-  
-  print $log "--- build ", time, '---', "\n";
 
   my $libdir = Path::Class::Dir->new(
     Alien::TinyCC->libtcc_library_path,
@@ -60,7 +47,6 @@ sub tcc_build
     do {
       my $from = $libdir->file('libtcc.dll');
       my $to   = $share->file('libtcc.dll');
-      print $log "copy $from => $to", "\n";
       copy($from => $to)
       || die "unable to copy $from => $to $!";
     };
@@ -71,7 +57,6 @@ sub tcc_build
     {
       my $from = $file;
       my $to   = $share->file('lib', basename $file);
-      print $log "copy $from $to", "\n";
       copy($from => $to)
       || die "unable to copy $from => $to $!";
     }
@@ -79,35 +64,23 @@ sub tcc_build
   else
   {
     my $lib = $libdir->file('libtcc.a');
-    print $log "lib = $lib", "\n";
 
     die "unable to find libtcc.a" unless -f $lib;
 
     my $tmp = Path::Class::Dir->new(tempdir( CLEANUP => 1 ));
-    print $log "tmp = $tmp", "\n";
 
     do {
       local $CWD = $tmp;
       my $ar = Archive::Ar->new;
       $ar->read($lib->stringify);
-      foreach my $old ($ar->list_files)
-      {
-        my $new = $old;
-        $new =~ s{\0+$}{};
-        next if $new eq $old;
-        $ar->rename($old, $new);
-      }
-      $ar->extract || die $ar->error;
+      $ar->extract;
     };
     my @obj = grep /\.(o|obj)$/, $tmp->children;
-    print $log "obj = $_", "\n" for @obj;
 
     my @cmd = ($Config{cc}, '-o' => $share->file("libtcc.$Config{dlext}"), '-shared', @obj);
-    print $log "+ @cmd\n";
 
-    print "+ @cmd\n";
+    print "% @cmd\n";
     system @cmd;
-    die if $?;
   }
 }
 
