@@ -2,9 +2,9 @@ package FFI::TinyCC::Inline;
 
 use strict;
 use warnings;
-use 5.008001;
-use FFI::Platypus;
+use v5.10;
 use FFI::TinyCC;
+use FFI::Raw;
 use Carp qw( croak );
 use base qw( Exporter );
 
@@ -12,30 +12,26 @@ our @EXPORT_OK = qw( tcc_inline tcc_eval );
 our @EXPORT = @EXPORT_OK;
 
 # ABSTRACT: Embed Tiny C code in your Perl program
-our $VERSION = '0.17_02'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 
-my $ffi = FFI::Platypus->new;
-$ffi->load_custom_type( 'StringArray' => 'string_array' );
-
-# TODO: support platypus types like pointers and arrays
 my %typemap = (
-  'int'            => 'int',
-  'signed int'     => 'signed int',
-  'unsigned int'   => 'unsigned int',
-  'void'           => 'void',
-  'short'          => 'short',
-  'signed short'   => 'signed short',
-  'unsigned short' => 'unsigned short',
-  'long'           => 'long',
-  'signed long'    => 'signed long',
-  'unsigned long'  => 'unsigned long',
-  'char'           => 'char',
-  'signed char'    => 'signed char',
-  'unsigned char'  => 'unsigned char',
-  'float'          => 'float',
-  'double'         => 'double',
-  'char *'         => 'string',
+  'int'            => FFI::Raw::int,
+  'signed int'     => FFI::Raw::int,
+  'unsigned int'   => FFI::Raw::uint,
+  'void'           => FFI::Raw::void,
+  'short'          => FFI::Raw::short,
+  'signed short'   => FFI::Raw::short,
+  'unsigned short' => FFI::Raw::ushort,
+  'long'           => FFI::Raw::long,
+  'signed long'    => FFI::Raw::long,
+  'unsigned long'  => FFI::Raw::ulong,
+  'char'           => FFI::Raw::char,
+  'signed char'    => FFI::Raw::char,
+  'unsigned char'  => FFI::Raw::uchar,
+  'float'          => FFI::Raw::float,
+  'double'         => FFI::Raw::double,
+  'char *'         => FFI::Raw::str,
 );
 
 sub _typemap ($)
@@ -44,7 +40,7 @@ sub _typemap ($)
   $type =~ s{^const }{};
   return $typemap{$type}
     if defined $typemap{$type};
-  return 'opaque' if $type =~ /\*$/;
+  return FFI::Raw::ptr if $type =~ /\*$/;
   croak "unknown type: $type";
 }
 
@@ -53,21 +49,25 @@ sub _generate_sub ($$$)
   my($func_name, $func, $tcc) = @_;
   my $sub;
   
-  my $address = $tcc->get_symbol($func_name);
-  
   if(@{ $func->{arg_types} } == 2
   && $func->{arg_types}->[0] eq 'int'
   && $func->{arg_types}->[1] =~ /^(const |)char \*\*$/)
   {
-    my $f = $ffi->function($address => ['int','string_array'] => _typemap $func->{return_type});
+    my $ffi = $tcc->get_ffi_raw($func_name, _typemap $func->{return_type}, FFI::Raw::int, FFI::Raw::ptr);
     $sub = sub {
-      $f->call(scalar @_, \@_);
+      my $argc = scalar @_;
+      my @c_strings = map { "$_\0" } @_;
+      my $ptrs = pack 'P' x $argc, @c_strings;
+      my $argv = unpack 'L!', pack 'P', $ptrs;
+      $ffi->call($argc, $argv);
     };
   }
   else
   {
-    my $f = $ffi->function($address => [map { _typemap $_ } @{ $func->{arg_types} }] => _typemap $func->{return_type});
-    $sub = sub { $f->call(@_) };
+    my @types = map { _typemap $_ } ($func->{return_type}, @{ $func->{arg_types} });
+    my $ffi = $tcc->get_ffi_raw($func_name, @types);
+    no strict 'refs';
+    $sub = sub { $ffi->call(@_) };
   }
   
   $sub;
@@ -81,15 +81,8 @@ sub import
   if(defined $rest[0] && defined $rest[1]
   && $rest[0] eq 'options')
   {
-    if($] >= 5.010)
-    {
-      shift @rest;
-      $^H{"FFI::TinyCC::Inline/options"} = shift @rest;
-    }
-    else
-    {
-      croak "options not supported on Perl 5.8";
-    }
+    shift @rest;
+    $^H{"FFI::TinyCC::Inline/options"} = shift @rest;
   }
   
   return unless @rest > 0;
@@ -322,7 +315,7 @@ FFI::TinyCC::Inline - Embed Tiny C code in your Perl program
 
 =head1 VERSION
 
-version 0.17_02
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -335,7 +328,7 @@ version 0.17_02
    }
  };
  
- print square(4), "\n"; # prints 16
+ say square(4); # prints 16
 
  use FFI::TinyCC::Inline qw( tcc_eval );
  
@@ -350,19 +343,17 @@ version 0.17_02
 =head1 DESCRIPTION
 
 This module provides a simplified interface to FFI::TinyCC, that allows you
-to write Perl subs in C.  It is inspired by L<XS::TCC>, but it uses L<FFI::Platypus>
+to write Perl subs in C.  It is inspired by L<XS::TCC>, but it uses L<FFI::Raw>
 to create bindings instead of XS.
 
 =head1 OPTIONS
 
-[requires Perl 5.10.0 or better]
-
 You can specify Tiny C options using the scoped pragmata, like so:
 
  use FFI::TinyCC::Inline options => "-I/foo/include -L/foo/lib -DFOO=1";
  
  # prints 1
- print tcc_eval q{
+ say tcc_eval q{
  #include <foo.h> /* will search /foo/include
  int main()
  {
@@ -388,7 +379,7 @@ types.
    }
  };
  
- print foo(1,2,3), "\n"; # prints 6
+ say foo(1,2,3); # prints 6
 
 The special argument type of C<(int argc, char **argv)> is recognized and
 will be translated from the list of arguments passed in.  Example:
@@ -421,20 +412,6 @@ Returns the result.
 
 =back
 
-=head1 BUNDLED SOFTWARE
-
-This package also comes with a parser that was shamelessly stolen from L<XS::TCC>,
-which I strongly suspect was itself shamelessly "borrowed" from 
-L<Inline::C::Parser::RegExp>
-
-The license details for the parser are:
-
-Copyright 2002 Brian Ingerson
-Copyright 2008, 2010-2012 Sisyphus
-Copyright 2013 Steffen Muellero
-
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
 =cut
 
 =head1 AUTHOR
@@ -443,7 +420,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Graham Ollis.
+This software is copyright (c) 2014 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
